@@ -5,11 +5,13 @@ package Fake::Our;
 #
 # http://search.cpan.org/dist/Fake-Our/
 #
-# Copyright (c) 2014, 2015 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2014, 2015, 2017 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
-$Fake::Our::VERSION = 0.05;
+$VERSION =
+$VERSION = '0.06';
 
+BEGIN { pop @INC if $INC[-1] eq '.' } # CVE-2016-1238: Important unsafe module load path flaw
 use 5.00503;
 # use strict; # since import() use $^H
 local $^W = 1;
@@ -53,7 +55,7 @@ Moreover, this module is incomplete and limited.
 
 =head1 AUTHOR
 
-INABA Hitoshi E<lt>ina@cpan.orgE<gt>
+INABA Hitoshi E<lt>ina@cpan.orgE<gt> in a CPAN
 
 This project was originated by INABA Hitoshi.
 
